==> speech-analytic-testing_3.7.0_database.tar.gz: database/mssql/procedures/GetSentimentAnalysisResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetSentimentAnalysisResult] (
	@VCC varchar(50),
	@InteractionId varchar(250),
	@InteractionSection numeric(5,0),
	@InteractionPart numeric(5,0),
	@EndDate varchar(50)
   
	)
AS
BEGIN
	SET NOCOUNT ON

	
	DROP TABLE IF EXISTS #SentimentResultDefault
	CREATE TABLE #SentimentResultDefault(
	analysisType VARCHAR(50),
	intentId VARCHAR(50),
	score NUMERIC(10,5),
	[status] INT
	
	)

	 IF EXISTS(SELECT 1 FROM [dbo].[SentimentAnalysisResult] SAR WHERE SAR.[VCC] = @VCC
				AND SAR.[InteractionId] = @InteractionId
				AND SAR.[InteractionSection] = @InteractionSection
				AND SAR.[InteractionPart] = @InteractionPart
				AND ISNULL(CONVERT(DATE, SAR.[EndDate], 105), '') = ISNULL(@EndDate, '') )
	BEGIN
	INSERT INTO  #SentimentResultDefault
		SELECT DISTINCT 'client', intentid, 0, 0 from intent where vcc = @VCC and AppId like '%sentiment-%'
		UNION
		SELECT DISTINCT 'agent', intentid, 0, 0 from intent where vcc = @VCC and AppId like '%sentiment-%'
		UNION
		SELECT DISTINCT 'general', intentid, 0, 0 from intent where vcc = @VCC and AppId like '%sentiment-%'

	END

	INSERT INTO #SentimentResultDefault
		SELECT [AnalysisType]					'analysisType',
				[SentimentId]					'intentId',
				[Score]							'averageResult',			
				[MaxScore]
			FROM [dbo].[SentimentAnalysisResult] SAR (NOLOCK)
	
			WHERE SAR.[VCC] = @VCC
					AND SAR.[InteractionId] = @InteractionId
					AND SAR.[InteractionSection] = @InteractionSection
					AND SAR.[InteractionPart] = @InteractionPart
					--AND ISNULL(CONVERT(DATE, SAR.[EndDate], 105), '') = ISNULL(@EndDate, '')
	
	DROP TABLE IF EXISTS #SentimentResultDefaultMax
	
	SELECT analysisType,intentId,MAX(score) as 'score',MAX([status]) 'status'
		INTO  #SentimentResultDefaultMax
		FROM  #SentimentResultDefault
		GROUP BY analysisType,intentId
	
   
				
	SELECT [AnalysisType]				'analysisType',
		   [intentId]					'intentId',
		   [Score]						'averageResult',
		   CASE WHEN [status] = 0 THEN	'normal' 
				ELSE 'max' 
				END						'status'
			
		FROM #SentimentResultDefaultMax
	
	

		
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.8.2_database.tar.gz: database/mssql/procedures/GetSentimentAnalysisResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetSentimentAnalysisResult] (
	@VCC varchar(50),
	@InteractionId varchar(250),
	@InteractionSection numeric(5,0),
	@InteractionPart numeric(5,0),
	@EndDate varchar(50)
   
	)
AS
BEGIN
	SET NOCOUNT ON

	
	DROP TABLE IF EXISTS #SentimentResultDefault
	CREATE TABLE #SentimentResultDefault(
	analysisType VARCHAR(50),
	intentId VARCHAR(50),
	score NUMERIC(10,5),
	[status] INT
	
	)

	 IF EXISTS(SELECT 1 FROM [dbo].[SentimentAnalysisResult] SAR WHERE SAR.[VCC] = @VCC
				AND SAR.[InteractionId] = @InteractionId
				AND SAR.[InteractionSection] = @InteractionSection
				AND SAR.[InteractionPart] = @InteractionPart
				AND ISNULL(CONVERT(DATE, SAR.[EndDate], 105), '') = ISNULL(@EndDate, '') )
	BEGIN
	INSERT INTO  #SentimentResultDefault
		SELECT DISTINCT 'client', intentid, 0, 0 from intent where vcc = @VCC and [name] like 'sentiment-%'
		UNION
		SELECT DISTINCT 'agent', intentid, 0, 0 from intent where vcc = @VCC and [name] like 'sentiment-%'
		UNION
		SELECT DISTINCT 'general', intentid, 0, 0 from intent where vcc = @VCC and [name] like 'sentiment-%'

	END

	INSERT INTO #SentimentResultDefault
		SELECT [AnalysisType]					'analysisType',
				[SentimentId]					'intentId',
				[Score]							'averageResult',			
				[MaxScore]
			FROM [dbo].[SentimentAnalysisResult] SAR (NOLOCK)
	
			WHERE SAR.[VCC] = @VCC
					AND SAR.[InteractionId] = @InteractionId
					AND SAR.[InteractionSection] = @InteractionSection
					AND SAR.[InteractionPart] = @InteractionPart
					AND ISNULL(CONVERT(DATE, SAR.[EndDate], 105), '') = ISNULL(@EndDate, '')
	
	DROP TABLE IF EXISTS #SentimentResultDefaultMax
	
	SELECT analysisType,intentId,MAX(score) as 'score',MAX([status]) 'status'
		INTO  #SentimentResultDefaultMax
		FROM  #SentimentResultDefault
		GROUP BY analysisType,intentId
	
   
				
	SELECT [AnalysisType]				'analysisType',
		   [intentId]					'intentId',
		   [Score]						'averageResult',
		   CASE WHEN [status] = 0 THEN	'normal' 
				ELSE 'max' 
				END						'status'
			
		FROM #SentimentResultDefaultMax
	
	

		
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
